RUSTCORE
RU EN
RUSTCORE TOOLS

Инструменты

Онлайн расчёт крафта ресурсов, рейд-калькулятор, переработка предметов, база NPC квестов и отслеживание обновлений и коммитов кода.

📜 Обновления и коммиты Rust

Отслеживание обновлений Steam-депотов, номеров билдов и коммитов в исходном коде разработчиков Facepunch.

👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main/cache_ocean_path)
12.10.2026 18:49
Codegen
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:48
Remove three unused floats (skincol, skintex, skinmesh) from all player net messages that havent been used since 2016 Defaults were set to -1 so included in the proto Saves 17 bytes per player
👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main/cache_ocean_path)
12.10.2026 18:48
Optimize server startup time by caching the ocean patrol path on disk (158s -> 138s) - same idea as server occlusion grid being saved - can increase version number to regenerate next restart - convar `regenerate_ocean_path` will cause it to regenerate it next startup too
👨‍💻
cipeaX в репозитории rust_reboot (ветка main/automated_testing)
12.10.2026 18:42
merge from main
👨‍💻
Flavien в репозитории rust_reboot (ветка main/gunfiring_optims)
12.10.2026 18:40
Prewarm 5 copies of each ricochet effect instead of 1, first magazine dumped after connecting created up to 2 more per prefab at ~0.5ms each
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:35
Stop networking IO wire origin data and duplicate slack levels to clients Saves ~34 B per wired slot + ~5 B per wire point on network load
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:30
Fix flame turret sending two updates per trigger change instead of one Saves 60 B~ per nearby player each time the turret turns on or off
👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main/cache_entity_links)
12.10.2026 18:30
Update test list
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:27
Stop water purifier sending two unchanged network updates per boil tick 30 B/s~ per nearby player
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:18
Dont send environment rainGraceStartTicks (only used on the server) Sends every 5 seconds. 54 → 44 B per update, so saves 10 B~ every per player every 5s
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:16
Door.SetOpen no longer sends a full network update when the door is already in the requested state (door closers re-close shut doors 3 s after every open/close cycle) Saves ~76 B per nearby player per call
👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main/cache_entity_links)
12.10.2026 18:14
merge from main -> cache_entity_links
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:09
Only send search light network updates when aim/flags change rather than per tick when mounted
👨‍💻
Martyn Chapman в репозитории rust_reboot (ветка ▆▋█▋)
12.10.2026 18:09
▄ ▉▄▉▆▄ ▇▋▍▄ ▄▅▇▆▊▍█▅▄▌█▋█▋▆▆▍▄▌▅▍▌█▉▋▌▍▉
👨‍💻
Martyn Chapman в репозитории rust_reboot (ветка ▅▅▋█)
12.10.2026 18:06
█▆▇▇▌▅ ▌▆▌▊ ▇█▋▋▍▇▄▉▄█▇▉▇█▅▉▄█▊▇▊▉▄▉█▌▅▌
👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main)
12.10.2026 18:06
merge from optimize_duplicate_player_check -> main
👨‍💻
Martyn Chapman в репозитории rust_reboot (ветка ▊▍▌▉▄▌██▋▊▄▅▍▅▊▋▉█▍█▆▆)
12.10.2026 18:06
▍ ▇▆▋ █ ▉▉▋█▉▅ ▄▊▅▌█ ▋▋▍▇▍▋▌▇▌ ▊█▉▋ ▍▉▋▌█▇▋▊▋▊█ ▇▊ ▅▄▉▅▍▍▆▄▄▉ ▅▄▇▅▉▌▌▋▄ ▍▍ █▄▇ ▆▅▋▅▌▄▅█▍▆ ▊▌▌▋▊▉▇▋▍▍▊ ▋▄▆▅ ▋▍ ▌██ ▋▊▍▅▍▌▅▄▅▄█▋▅▅▉▋▄▅▅ █▉ ▅▉▄▋█▄▉ ▄▄▄ ▆▄█▉▄▌ ▊▌▌ ▇▆▉▍▉▍ ▊▍▋▇▋▌
👨‍💻
Ian Henderson в репозитории rust_reboot (ветка main/network_optims)
12.10.2026 18:05
Dont send travelling vendor map marker updates 20 frames a second Saves 160 bytes per network tick when the vendor is out
👨‍💻
Jake_Rich в репозитории rust_reboot (ветка main)
12.10.2026 18:03
~ merge from optimize_enforce_limits -> main
👨‍💻
Flavien в репозитории rust_reboot (ветка main/gunfiring_optims)
12.10.2026 18:02
Create the pools LaunchProjectileClientside uses at bootstrap instead of on the first shot, avoids a ~365KB alloc when the first projectile of the session is fired